@@ -1,7 +1,7 @@
 package Module::List::Wildcard;
 
-our $DATE = '2020-09-21'; # DATE
-our $VERSION = '0.004006'; # VERSION
+our $DATE = '2020-12-22'; # DATE
+our $VERSION = '0.004007'; # VERSION
 
 #IFUNBUILT
 # # use strict 'subs', 'vars';
@@ -212,7 +212,7 @@ Module::List::Wildcard - A fork of Module::List that groks wildcard
 
 =head1 VERSION
 
-This document describes version 0.004006 of Module::List::Wildcard (from Perl distribution Module-List-Wildcard), released on 2020-09-21.
+This document describes version 0.004007 of Module::List::Wildcard (from Perl distribution Module-List-Wildcard), released on 2020-12-22.
 
 =head1 SYNOPSIS
 
@@ -251,7 +251,8 @@ Path separator is hard-coded as C</>.
 
 This boolean option can be set to true to recognize wildcard pattern in prefix.
 Wildcard patterns such as jokers (C<?>, C<*>, C<**>), classes (C<[a-z]>), as
-well as braces (C<{One,Two}>) are supported. C<**> implies recursive listing.
+well as braces (C<{One,Two}>) are supported. C<**> implies recursive listing
+(sets C<recurse> option to 1).
 
 Examples:
 
@@ -308,7 +309,7 @@ Source repository is at L<https://github.com/perlancar/perl-Module-List-Wildcard
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Module-List-Wildcard>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Module-List-Wildcard/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
